@@ -277,7 +277,7 @@ typedef struct
 #define LOGLUV_PUBLIC 1
 #endif
 
-#if defined(__GNUC__) || defined(__attribute__)
+#if defined(__GNUC__) || defined(__clang__) || defined(__attribute__)
 #define TIFF_ATTRIBUTE(x) __attribute__(x)
 #else
 #define TIFF_ATTRIBUTE(x) /*nothing*/
